@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2010-2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2010-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -84,14 +84,14 @@ class FileSystemManager(object):
                 'msdos': '83',
                 'ssd': ['discard'],
                 'type': ['hdd', 'usb-hdd']},
-        'nilfs2': {'defaultopt': defaultOpt,
-                   'format': '/sbin/mkfs.nilfs2',
-                   'formatparam': '{labelparam} {device}',
-                   'gpt': '8300',
-                   'label': '-L {labelname}',
-                   'msdos': '83',
-                   'ssd': [],
-                   'type': ['hdd', 'usb-hdd']},
+#        'nilfs2': {'defaultopt': defaultOpt,
+#                   'format': '/sbin/mkfs.nilfs2',
+#                   'formatparam': '{labelparam} {device}',
+#                   'gpt': '8300',
+#                   'label': '-L {labelname}',
+#                   'msdos': '83',
+#                   'ssd': [],
+#                   'type': ['hdd', 'usb-hdd']},
         'swap': {'defaultopt': ['sw'],
                  'format': '/sbin/mkswap',
                  'formatparam': '{device}',
